@@ -20,9 +20,11 @@ class FlaviusBase:
             self.ssl_ctx = None
             url = self.endpoint_dev
         else:
-            self.ssl_ctx = ssl.create_default_context()
-            self.ssl_ctx.load_cert_chain(certfile=conf.FLAVIUS_CRT_FILE,
-                                         keyfile=conf.FLAVIUS_KEY_FILE)
+            self.ssl_ctx = None
+            url = self.endpoint
+            # self.ssl_ctx = ssl.create_default_context()
+            # self.ssl_ctx.load_cert_chain(certfile=conf.FLAVIUS_CRT_FILE,
+            #                              keyfile=conf.FLAVIUS_KEY_FILE)
 
         self.search_url = url + search_url + self.make_get_parameter()
         self.create_url = url + create_url + self.make_get_parameter()
